/* link-personas-diff-stores.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from link-personas-diff-stores.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <folks/folks.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <folks-test.h>
#include <gio/gio.h>


#define TYPE_LINK_PERSONAS_DIFF_STORES_TESTS (link_personas_diff_stores_tests_get_type ())
#define LINK_PERSONAS_DIFF_STORES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS, LinkPersonasDiffStoresTests))
#define LINK_PERSONAS_DIFF_STORES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS, LinkPersonasDiffStoresTestsClass))
#define IS_LINK_PERSONAS_DIFF_STORES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS))
#define IS_LINK_PERSONAS_DIFF_STORES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS))
#define LINK_PERSONAS_DIFF_STORES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS, LinkPersonasDiffStoresTestsClass))

typedef struct _LinkPersonasDiffStoresTests LinkPersonasDiffStoresTests;
typedef struct _LinkPersonasDiffStoresTestsClass LinkPersonasDiffStoresTestsClass;
typedef struct _LinkPersonasDiffStoresTestsPrivate LinkPersonasDiffStoresTestsPrivate;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _LinkPersonasDiffStoresTestsAddPersonasData LinkPersonasDiffStoresTestsAddPersonasData;
typedef struct _LinkPersonasDiffStoresTestsIndividualsChangedAsyncData LinkPersonasDiffStoresTestsIndividualsChangedAsyncData;
typedef struct _LinkPersonasDiffStoresTestsCheckPersonasData LinkPersonasDiffStoresTestsCheckPersonasData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LinkPersonasDiffStoresTests {
	EdsTestTestCase parent_instance;
	LinkPersonasDiffStoresTestsPrivate * priv;
};

struct _LinkPersonasDiffStoresTestsClass {
	EdsTestTestCaseClass parent_class;
};

struct _LinkPersonasDiffStoresTestsPrivate {
	GMainLoop* _main_loop;
	EdsTestBackend* _eds_backend_other;
	FolksIndividualAggregator* _aggregator;
	gchar* _persona_fullname_1;
	gchar* _persona_fullname_2;
	gboolean _linking_fired;
	gboolean _linked_individual_found;
	gchar* _persona_iid_1;
	gchar* _persona_iid_2;
	GeeHashSet* _personas;
};

struct _Block1Data {
	int _ref_count_;
	LinkPersonasDiffStoresTests* self;
	FolksBackendStore* store;
	gpointer _async_data_;
};

struct _LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasDiffStoresTests* self;
	Block1Data* _data1_;
	FolksBackendStore* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	FolksIndividualAggregator* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	FolksIndividualAggregator* _tmp7_;
	GError* e;
	GError* _tmp8_;
	const gchar* _tmp9_;
	GError * _inner_error_;
};

struct _LinkPersonasDiffStoresTestsAddPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasDiffStoresTests* self;
	FolksPersonaStore* pstore1;
	FolksPersonaStore* pstore2;
	GHashTable* details1;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	GValue* v1;
	GValue _tmp3_;
	GValue _tmp4_;
	GValue* _tmp5_;
	GValue* _tmp6_;
	GValue* _tmp7_;
	const gchar* _tmp8_;
	GHashTable* _tmp9_;
	gchar* _tmp10_;
	GValue* _tmp11_;
	GHashTable* details2;
	GHashFunc _tmp12_;
	GEqualFunc _tmp13_;
	GHashTable* _tmp14_;
	GValue* v2;
	GValue _tmp15_;
	GValue _tmp16_;
	GValue* _tmp17_;
	GValue* _tmp18_;
	GValue* _tmp19_;
	const gchar* _tmp20_;
	GHashTable* _tmp21_;
	gchar* _tmp22_;
	GValue* _tmp23_;
	FolksIndividualAggregator* _tmp24_;
	FolksPersonaStore* _tmp25_;
	GHashTable* _tmp26_;
	FolksPersona* _tmp27_;
	FolksPersona* _tmp28_;
	FolksIndividualAggregator* _tmp29_;
	FolksPersonaStore* _tmp30_;
	GHashTable* _tmp31_;
	FolksPersona* _tmp32_;
	FolksPersona* _tmp33_;
	GError* e;
	GError* _tmp34_;
	const gchar* _tmp35_;
	GError * _inner_error_;
};

struct _LinkPersonasDiffStoresTestsIndividualsChangedAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasDiffStoresTests* self;
	GeeMultiMap* changes;
	GeeCollection* added;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeIterator* _i_it;
	GeeCollection* _tmp2_;
	GeeIterator* _tmp3_;
	GeeIterator* _tmp4_;
	gboolean _tmp5_;
	FolksIndividual* i;
	GeeIterator* _tmp6_;
	gpointer _tmp7_;
	FolksIndividual* _tmp8_;
	FolksIndividual* _tmp9_;
};

struct _LinkPersonasDiffStoresTestsCheckPersonasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	LinkPersonasDiffStoresTests* self;
	FolksIndividual* i;
	gboolean _tmp0_;
	FolksPersona* first_persona;
	GeeIterator* _p_it;
	FolksIndividual* _tmp1_;
	GeeSet* _tmp2_;
	GeeSet* _tmp3_;
	GeeIterator* _tmp4_;
	GeeIterator* _tmp5_;
	gboolean _tmp6_;
	FolksPersona* p;
	GeeIterator* _tmp7_;
	gpointer _tmp8_;
	FolksPersona* _tmp9_;
	FolksPersona* _tmp10_;
	gboolean _tmp11_;
	FolksIndividual* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	FolksPersona* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	GeeHashSet* _tmp21_;
	FolksPersona* _tmp22_;
	gboolean _tmp23_;
	FolksIndividual* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	FolksPersona* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	gchar* _tmp32_;
	GeeHashSet* _tmp33_;
	FolksPersona* _tmp34_;
	FolksIndividual* _tmp35_;
	GeeSet* _tmp36_;
	GeeSet* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
	gboolean first_persona_id;
	gboolean second_persona_id;
	GeeIterator* _p1_it;
	FolksIndividual* _tmp40_;
	GeeSet* _tmp41_;
	GeeSet* _tmp42_;
	GeeIterator* _tmp43_;
	GeeIterator* _tmp44_;
	gboolean _tmp45_;
	FolksPersona* p1;
	GeeIterator* _tmp46_;
	gpointer _tmp47_;
	FolksPersona* _tmp48_;
	const gchar* _tmp49_;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	FolksPersona* _tmp52_;
	const gchar* _tmp53_;
	const gchar* _tmp54_;
	const gchar* _tmp55_;
	gboolean _tmp56_;
	gboolean _tmp57_;
	gboolean _tmp58_;
	GMainLoop* _tmp59_;
	gboolean _tmp60_;
	GeeHashSet* _tmp61_;
	gint _tmp62_;
	gint _tmp63_;
	gboolean _tmp64_;
	FolksIndividualAggregator* _tmp65_;
	GeeHashSet* _tmp66_;
	GError* e;
	GError* _tmp67_;
	const gchar* _tmp68_;
	GError * _inner_error_;
};


static gpointer link_personas_diff_stores_tests_parent_class = NULL;

GType link_personas_diff_stores_tests_get_type (void) G_GNUC_CONST;
#define LINK_PERSONAS_DIFF_STORES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LINK_PERSONAS_DIFF_STORES_TESTS, LinkPersonasDiffStoresTestsPrivate))
enum  {
	LINK_PERSONAS_DIFF_STORES_TESTS_DUMMY_PROPERTY
};
LinkPersonasDiffStoresTests* link_personas_diff_stores_tests_new (void);
LinkPersonasDiffStoresTests* link_personas_diff_stores_tests_construct (GType object_type);
void link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores (LinkPersonasDiffStoresTests* self);
static void _link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores_folks_test_case_test_method (gpointer self);
static void link_personas_diff_stores_tests_real_set_up (FolksTestCase* base);
static void link_personas_diff_stores_tests_real_tear_down (FolksTestCase* base);
static void _link_personas_diff_stores_tests_test_linking_personas_async (LinkPersonasDiffStoresTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_test_linking_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_);
static void _link_personas_diff_stores_tests_test_linking_personas_async_data_free (gpointer _data);
static gboolean _link_personas_diff_stores_tests_test_linking_personas_async_co (LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void _link_personas_diff_stores_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_individuals_changed_cb (LinkPersonasDiffStoresTests* self, GeeMultiMap* changes);
static void __link_personas_diff_stores_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void ___lambda4_ (Block1Data* _data1_, GObject* obj, GParamSpec* pspec);
static FolksPersonaStore* _link_personas_diff_stores_tests_get_store (LinkPersonasDiffStoresTests* self, FolksBackendStore* store, const gchar* store_id);
static void _link_personas_diff_stores_tests_add_personas (LinkPersonasDiffStoresTests* self, FolksPersonaStore* pstore1, FolksPersonaStore* pstore2, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_add_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_);
static void ____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _link_personas_diff_stores_tests_add_personas_data_free (gpointer _data);
static gboolean _link_personas_diff_stores_tests_add_personas_co (LinkPersonasDiffStoresTestsAddPersonasData* _data_);
static void _g_free0_ (gpointer var);
static void _vala_GValue_free (GValue* self);
static void __vala_GValue_free0_ (gpointer var);
static GValue* _g_value_dup (GValue* self);
static void _link_personas_diff_stores_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_individuals_changed_async (LinkPersonasDiffStoresTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_individuals_changed_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_);
static void __lambda3_ (LinkPersonasDiffStoresTests* self, GObject* object, GAsyncResult* _result_);
static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _link_personas_diff_stores_tests_individuals_changed_async_data_free (gpointer _data);
static gboolean _link_personas_diff_stores_tests_individuals_changed_async_co (LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_);
static void _link_personas_diff_stores_tests_check_personas (LinkPersonasDiffStoresTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_check_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_);
static void _link_personas_diff_stores_tests_individuals_changed_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _link_personas_diff_stores_tests_check_personas_data_free (gpointer _data);
static gboolean _link_personas_diff_stores_tests_check_personas_co (LinkPersonasDiffStoresTestsCheckPersonasData* _data_);
static void _link_personas_diff_stores_tests_check_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void link_personas_diff_stores_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);


static void _link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores_folks_test_case_test_method (gpointer self) {
#line 41 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores ((LinkPersonasDiffStoresTests*) self);
#line 325 "link-personas-diff-stores.c"
}


LinkPersonasDiffStoresTests* link_personas_diff_stores_tests_construct (GType object_type) {
	LinkPersonasDiffStoresTests * self = NULL;
#line 39 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self = (LinkPersonasDiffStoresTests*) eds_test_test_case_construct (object_type, "LinkPersonasDiffStoresTests");
#line 41 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "test linking via local IDs using different PersonaStores", _link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores_folks_test_case_test_method, self);
#line 37 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return self;
#line 337 "link-personas-diff-stores.c"
}


LinkPersonasDiffStoresTests* link_personas_diff_stores_tests_new (void) {
#line 37 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return link_personas_diff_stores_tests_construct (TYPE_LINK_PERSONAS_DIFF_STORES_TESTS);
#line 344 "link-personas-diff-stores.c"
}


static void link_personas_diff_stores_tests_real_set_up (FolksTestCase* base) {
	LinkPersonasDiffStoresTests * self;
	EdsTestBackend* _tmp0_ = NULL;
	EdsTestBackend* _tmp1_ = NULL;
	EdsTestBackend* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	EdsTestBackend* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 45 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self = (LinkPersonasDiffStoresTests*) base;
#line 47 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	FOLKS_TEST_CASE_CLASS (link_personas_diff_stores_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 48 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = eds_test_backend_new ();
#line 48 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend_other);
#line 48 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_eds_backend_other = _tmp0_;
#line 49 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = self->priv->_eds_backend_other;
#line 49 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	eds_test_backend_set_up (_tmp1_, FALSE, "other");
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = ((EdsTestTestCase*) self)->eds_backend;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp3_ = eds_test_backend_get_address_book_uid (_tmp2_);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp4_ = _tmp3_;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp5_ = g_strconcat (_tmp4_, ":", NULL);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp6_ = _tmp5_;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp7_ = self->priv->_eds_backend_other;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp8_ = eds_test_backend_get_address_book_uid (_tmp7_);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp9_ = _tmp8_;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp10_ = g_strconcat (_tmp6_, _tmp9_, NULL);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp11_ = _tmp10_;
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_setenv ("FOLKS_BACKEND_EDS_USE_ADDRESS_BOOKS", _tmp11_, TRUE);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (_tmp11_);
#line 51 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (_tmp6_);
#line 402 "link-personas-diff-stores.c"
}


static void link_personas_diff_stores_tests_real_tear_down (FolksTestCase* base) {
	LinkPersonasDiffStoresTests * self;
	EdsTestBackend* _tmp0_ = NULL;
#line 57 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self = (LinkPersonasDiffStoresTests*) base;
#line 59 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = self->priv->_eds_backend_other;
#line 59 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	eds_test_backend_tear_down (_tmp0_);
#line 60 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend_other);
#line 60 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_eds_backend_other = NULL;
#line 61 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	FOLKS_TEST_CASE_CLASS (link_personas_diff_stores_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, EDS_TEST_TYPE_TEST_CASE, EdsTestTestCase));
#line 421 "link-personas-diff-stores.c"
}


void link_personas_diff_stores_tests_test_linking_via_local_ids_diff_stores (LinkPersonasDiffStoresTests* self) {
	GMainLoop* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GMainLoop* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 64 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (self != NULL);
#line 66 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 66 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 66 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_main_loop = _tmp0_;
#line 67 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = g_strdup ("persona #1");
#line 67 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 67 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_persona_fullname_1 = _tmp1_;
#line 68 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = g_strdup ("persona #2");
#line 68 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 68 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_persona_fullname_2 = _tmp2_;
#line 69 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp3_ = gee_hash_set_new (FOLKS_TYPE_PERSONA, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 69 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (self->priv->_personas);
#line 69 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_personas = _tmp3_;
#line 70 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_linking_fired = FALSE;
#line 71 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp4_ = g_strdup ("");
#line 71 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 71 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_persona_iid_1 = _tmp4_;
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp5_ = g_strdup ("");
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 72 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_persona_iid_2 = _tmp5_;
#line 73 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_linked_individual_found = FALSE;
#line 75 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_test_linking_personas_async (self, NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp6_ = self->priv->_main_loop;
#line 77 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_test_utils_loop_run_with_timeout (_tmp6_, 8);
#line 79 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp7_ = self->priv->_linked_individual_found;
#line 79 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_vala_assert (_tmp7_ == TRUE, "this._linked_individual_found == true");
#line 81 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 81 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_aggregator = NULL;
#line 82 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 82 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv->_main_loop = NULL;
#line 494 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_test_linking_personas_async_data_free (gpointer _data) {
	LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_slice_free (LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData, _data_);
#line 505 "link-personas-diff-stores.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return self ? g_object_ref (self) : NULL;
#line 512 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_test_linking_personas_async (LinkPersonasDiffStoresTests* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_;
	LinkPersonasDiffStoresTests* _tmp0_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_slice_new0 (LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_diff_stores_tests_test_linking_personas_async);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_diff_stores_tests_test_linking_personas_async_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_test_linking_personas_async_co (_data_);
#line 531 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_test_linking_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_) {
	LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 539 "link-personas-diff-stores.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return _data1_;
#line 548 "link-personas-diff-stores.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 557 "link-personas-diff-stores.c"
		LinkPersonasDiffStoresTests* self;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		self = _data1_->self;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_data1_->store);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (self);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_slice_free (Block1Data, _data1_);
#line 567 "link-personas-diff-stores.c"
	}
}


static void _link_personas_diff_stores_tests_test_linking_personas_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = _user_data_;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_source_object_ = source_object;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_res_ = _res_;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_test_linking_personas_async_co (_data_);
#line 582 "link-personas-diff-stores.c"
}


static void __link_personas_diff_stores_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 90 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_individuals_changed_cb ((LinkPersonasDiffStoresTests*) self, changes);
#line 589 "link-personas-diff-stores.c"
}


static void ___lambda4_ (Block1Data* _data1_, GObject* obj, GParamSpec* pspec) {
	LinkPersonasDiffStoresTests* self;
	FolksPersonaStore* pstore = NULL;
	EdsTestBackend* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	FolksPersonaStore* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	FolksPersonaStore* pstore2 = NULL;
	EdsTestBackend* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	FolksPersonaStore* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self = _data1_->self;
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (obj != NULL);
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (pspec != NULL);
#line 101 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = ((EdsTestTestCase*) self)->eds_backend;
#line 101 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = eds_test_backend_get_address_book_uid (_tmp0_);
#line 101 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = _tmp1_;
#line 101 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp3_ = _link_personas_diff_stores_tests_get_store (self, _data1_->store, _tmp2_);
#line 101 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	pstore = _tmp3_;
#line 103 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_vala_assert (pstore != NULL, "pstore != null");
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp4_ = folks_persona_store_get_is_prepared (pstore);
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp5_ = _tmp4_;
#line 104 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_vala_assert (_tmp5_ == TRUE, "pstore.is_prepared == true");
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp6_ = self->priv->_eds_backend_other;
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp7_ = eds_test_backend_get_address_book_uid (_tmp6_);
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp8_ = _tmp7_;
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp9_ = _link_personas_diff_stores_tests_get_store (self, _data1_->store, _tmp8_);
#line 106 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	pstore2 = _tmp9_;
#line 108 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_vala_assert (pstore2 != NULL, "pstore2 != null");
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp10_ = folks_persona_store_get_is_prepared (pstore2);
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp11_ = _tmp10_;
#line 109 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_vala_assert (_tmp11_ == TRUE, "pstore2.is_prepared == true");
#line 111 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_add_personas (self, pstore, pstore2, NULL, NULL);
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (pstore2);
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (pstore);
#line 657 "link-personas-diff-stores.c"
}


static void ____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	___lambda4_ (self, _sender, pspec);
#line 664 "link-personas-diff-stores.c"
}


static gboolean _link_personas_diff_stores_tests_test_linking_personas_async_co (LinkPersonasDiffStoresTestsTestLinkingPersonasAsyncData* _data_) {
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	switch (_data_->_state_) {
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 0:
#line 673 "link-personas-diff-stores.c"
		goto _state_0;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 1:
#line 677 "link-personas-diff-stores.c"
		goto _state_1;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 2:
#line 681 "link-personas-diff-stores.c"
		goto _state_2;
		default:
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_assert_not_reached ();
#line 686 "link-personas-diff-stores.c"
	}
	_state_0:
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_ = g_slice_new0 (Block1Data);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_->_ref_count_ = 1;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_->self = g_object_ref (_data_->self);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_->_async_data_ = _data_;
#line 87 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = folks_backend_store_dup ();
#line 87 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_->store = _data_->_tmp0_;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_state_ = 1;
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_backend_store_prepare (_data_->_data1_->store, _link_personas_diff_stores_tests_test_linking_personas_async_ready, _data_);
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return FALSE;
#line 709 "link-personas-diff-stores.c"
	_state_1:
#line 88 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_backend_store_prepare_finish (_data_->_data1_->store, _data_->_res_);
#line 89 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = NULL;
#line 89 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = folks_individual_aggregator_dup ();
#line 89 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->self->priv->_aggregator);
#line 89 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->self->priv->_aggregator = _data_->_tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp2_ = NULL;
#line 90 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp2_ = _data_->self->priv->_aggregator;
#line 90 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_signal_connect_object (_data_->_tmp2_, "individuals-changed-detailed", (GCallback) __link_personas_diff_stores_tests_individuals_changed_cb_folks_individual_aggregator_individuals_changed_detailed, _data_->self, 0);
#line 727 "link-personas-diff-stores.c"
	{
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = _data_->self->priv->_aggregator;
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_state_ = 2;
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		folks_individual_aggregator_prepare (_data_->_tmp3_, _link_personas_diff_stores_tests_test_linking_personas_async_ready, _data_);
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 739 "link-personas-diff-stores.c"
		_state_2:
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 94 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_inner_error_ != NULL) {
#line 745 "link-personas-diff-stores.c"
			goto __catch0_g_error;
		}
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp4_ = NULL;
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp4_ = _data_->self->priv->_aggregator;
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp5_ = FALSE;
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp5_ = folks_individual_aggregator_get_is_prepared (_data_->_tmp4_);
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp6_ = FALSE;
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 95 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_vala_assert (_data_->_tmp6_, "this._aggregator.is_prepared");
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp7_ = NULL;
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp7_ = _data_->self->priv->_aggregator;
#line 99 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_signal_connect_data ((GObject*) _data_->_tmp7_, "notify::is-quiescent", (GCallback) ____lambda4__g_object_notify, block1_data_ref (_data_->_data1_), (GClosureNotify) block1_data_unref, 0);
#line 768 "link-personas-diff-stores.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->e = _data_->_inner_error_;
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_inner_error_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp8_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp8_ = _data_->e;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp9_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp9_ = _data_->_tmp8_->message;
#line 116 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_warning ("link-personas-diff-stores.vala:116: Error when calling prepare: %s\n", _data_->_tmp9_);
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_error_free0 (_data_->e);
#line 789 "link-personas-diff-stores.c"
	}
	__finally0:
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_inner_error_ != NULL) {
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		block1_data_unref (_data_->_data1_);
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_data1_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_clear_error (&_data_->_inner_error_);
#line 92 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 804 "link-personas-diff-stores.c"
	}
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	block1_data_unref (_data_->_data1_);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_data1_ = NULL;
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_state_ == 0) {
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 814 "link-personas-diff-stores.c"
	} else {
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 818 "link-personas-diff-stores.c"
	}
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_object_unref (_data_->_async_result);
#line 85 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return FALSE;
#line 824 "link-personas-diff-stores.c"
}


static FolksPersonaStore* _link_personas_diff_stores_tests_get_store (LinkPersonasDiffStoresTests* self, FolksBackendStore* store, const gchar* store_id) {
	FolksPersonaStore* result = NULL;
	FolksPersonaStore* pstore = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 120 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_val_if_fail (store != NULL, NULL);
#line 120 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_val_if_fail (store_id != NULL, NULL);
#line 122 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	pstore = NULL;
#line 839 "link-personas-diff-stores.c"
	{
		GeeIterator* _backend_it = NULL;
		FolksBackendStore* _tmp0_ = NULL;
		GeeMap* _tmp1_ = NULL;
		GeeMap* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp0_ = store;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp1_ = folks_backend_store_get_enabled_backends (_tmp0_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp2_ = _tmp1_;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp3_ = gee_map_get_values (_tmp2_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp4_ = _tmp3_;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp5_ = _tmp4_;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_tmp7_ = _tmp6_;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_tmp5_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_backend_it = _tmp7_;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		while (TRUE) {
#line 872 "link-personas-diff-stores.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksBackend* backend = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksBackend* _tmp12_ = NULL;
			GeeMap* _tmp13_ = NULL;
			GeeMap* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			FolksPersonaStore* _tmp17_ = NULL;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp8_ = _backend_it;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (!_tmp9_) {
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				break;
#line 892 "link-personas-diff-stores.c"
			}
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp10_ = _backend_it;
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			backend = (FolksBackend*) _tmp11_;
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp12_ = backend;
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp13_ = folks_backend_get_persona_stores (_tmp12_);
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp14_ = _tmp13_;
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp15_ = store_id;
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp16_ = gee_map_get (_tmp14_, _tmp15_);
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (pstore);
#line 125 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			pstore = (FolksPersonaStore*) _tmp16_;
#line 126 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_tmp17_ = pstore;
#line 126 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_tmp17_ != NULL) {
#line 127 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_g_object_unref0 (backend);
#line 127 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				break;
#line 922 "link-personas-diff-stores.c"
			}
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (backend);
#line 926 "link-personas-diff-stores.c"
		}
#line 123 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_backend_it);
#line 930 "link-personas-diff-stores.c"
	}
#line 129 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	result = pstore;
#line 129 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return result;
#line 936 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_add_personas_data_free (gpointer _data) {
	LinkPersonasDiffStoresTestsAddPersonasData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->pstore1);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->pstore2);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_slice_free (LinkPersonasDiffStoresTestsAddPersonasData, _data_);
#line 951 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_add_personas (LinkPersonasDiffStoresTests* self, FolksPersonaStore* pstore1, FolksPersonaStore* pstore2, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsAddPersonasData* _data_;
	LinkPersonasDiffStoresTests* _tmp0_ = NULL;
	FolksPersonaStore* _tmp1_ = NULL;
	FolksPersonaStore* _tmp2_ = NULL;
	FolksPersonaStore* _tmp3_ = NULL;
	FolksPersonaStore* _tmp4_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_slice_new0 (LinkPersonasDiffStoresTestsAddPersonasData);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_diff_stores_tests_add_personas);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_diff_stores_tests_add_personas_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = pstore1;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->pstore1);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->pstore1 = _tmp2_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp3_ = pstore2;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->pstore2);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->pstore2 = _tmp4_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_add_personas_co (_data_);
#line 990 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_add_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_) {
	LinkPersonasDiffStoresTestsAddPersonasData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 998 "link-personas-diff-stores.c"
}


static void _g_free0_ (gpointer var) {
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	var = (g_free (var), NULL);
#line 1005 "link-personas-diff-stores.c"
}


static void _vala_GValue_free (GValue* self) {
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_value_unset (self);
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_free (self);
#line 1014 "link-personas-diff-stores.c"
}


static void __vala_GValue_free0_ (gpointer var) {
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	(var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL));
#line 1021 "link-personas-diff-stores.c"
}


static GValue* _g_value_dup (GValue* self) {
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 1028 "link-personas-diff-stores.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return self ? _g_value_dup (self) : NULL;
#line 1035 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_add_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsAddPersonasData* _data_;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = _user_data_;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_source_object_ = source_object;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_res_ = _res_;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_add_personas_co (_data_);
#line 1049 "link-personas-diff-stores.c"
}


static gboolean _link_personas_diff_stores_tests_add_personas_co (LinkPersonasDiffStoresTestsAddPersonasData* _data_) {
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	switch (_data_->_state_) {
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 0:
#line 1058 "link-personas-diff-stores.c"
		goto _state_0;
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 1:
#line 1062 "link-personas-diff-stores.c"
		goto _state_1;
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 2:
#line 1066 "link-personas-diff-stores.c"
		goto _state_2;
		default:
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_assert_not_reached ();
#line 1071 "link-personas-diff-stores.c"
	}
	_state_0:
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = g_str_hash;
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = g_str_equal;
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp2_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp2_ = g_hash_table_new_full (_data_->_tmp0_, _data_->_tmp1_, _g_free0_, __vala_GValue_free0_);
#line 145 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->details1 = _data_->_tmp2_;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	memset (&_data_->_tmp3_, 0, sizeof (GValue));
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_value_init (&_data_->_tmp3_, G_TYPE_STRING);
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GValue));
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp5_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp5_ = __g_value_dup0 (&_data_->_tmp4_);
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp6_ = NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	G_IS_VALUE (&_data_->_tmp4_) ? (g_value_unset (&_data_->_tmp4_), NULL) : NULL;
#line 147 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->v1 = _data_->_tmp6_;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp7_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp7_ = _data_->v1;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp8_ = NULL;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp8_ = _data_->self->priv->_persona_fullname_1;
#line 148 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_value_set_string (_data_->_tmp7_, _data_->_tmp8_);
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp9_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp9_ = _data_->details1;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp10_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp10_ = g_strdup ("full-name");
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp11_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp11_ = _data_->v1;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->v1 = NULL;
#line 149 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_hash_table_insert (_data_->_tmp9_, _data_->_tmp10_, _data_->_tmp11_);
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp12_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp12_ = g_str_hash;
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp13_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp13_ = g_str_equal;
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp14_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp14_ = g_hash_table_new_full (_data_->_tmp12_, _data_->_tmp13_, _g_free0_, __vala_GValue_free0_);
#line 151 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->details2 = _data_->_tmp14_;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	memset (&_data_->_tmp15_, 0, sizeof (GValue));
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_value_init (&_data_->_tmp15_, G_TYPE_STRING);
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	memset (&_data_->_tmp16_, 0, sizeof (GValue));
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp17_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp17_ = __g_value_dup0 (&_data_->_tmp16_);
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp18_ = NULL;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	G_IS_VALUE (&_data_->_tmp16_) ? (g_value_unset (&_data_->_tmp16_), NULL) : NULL;
#line 153 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->v2 = _data_->_tmp18_;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp19_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp19_ = _data_->v2;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp20_ = NULL;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp20_ = _data_->self->priv->_persona_fullname_2;
#line 154 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_value_set_string (_data_->_tmp19_, _data_->_tmp20_);
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp21_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp21_ = _data_->details2;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp22_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp22_ = g_strdup ("full-name");
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp23_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp23_ = _data_->v2;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->v2 = NULL;
#line 155 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_hash_table_insert (_data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_);
#line 1194 "link-personas-diff-stores.c"
	{
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp24_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp24_ = _data_->self->priv->_aggregator;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp25_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp25_ = _data_->pstore1;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp26_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp26_ = _data_->details1;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_state_ = 1;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp24_, NULL, _data_->_tmp25_, _data_->_tmp26_, _link_personas_diff_stores_tests_add_personas_ready, _data_);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 1214 "link-personas-diff-stores.c"
		_state_1:
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp27_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp27_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp24_, _data_->_res_, &_data_->_inner_error_);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp28_ = NULL;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_data_->_tmp28_);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_inner_error_ != NULL) {
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1230 "link-personas-diff-stores.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			__vala_GValue_free0 (_data_->v2);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			__vala_GValue_free0 (_data_->v1);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_clear_error (&_data_->_inner_error_);
#line 159 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			return FALSE;
#line 1247 "link-personas-diff-stores.c"
		}
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp29_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp29_ = _data_->self->priv->_aggregator;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp30_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp30_ = _data_->pstore2;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp31_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp31_ = _data_->details2;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_state_ = 2;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		folks_individual_aggregator_add_persona_from_details (_data_->_tmp29_, NULL, _data_->_tmp30_, _data_->_tmp31_, _link_personas_diff_stores_tests_add_personas_ready, _data_);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 1267 "link-personas-diff-stores.c"
		_state_2:
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp32_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp32_ = folks_individual_aggregator_add_persona_from_details_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp33_ = NULL;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_data_->_tmp33_);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_inner_error_ != NULL) {
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_data_->_inner_error_->domain == FOLKS_INDIVIDUAL_AGGREGATOR_ERROR) {
#line 1283 "link-personas-diff-stores.c"
				goto __catch1_folks_individual_aggregator_error;
			}
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			__vala_GValue_free0 (_data_->v2);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_hash_table_unref0 (_data_->details2);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			__vala_GValue_free0 (_data_->v1);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_hash_table_unref0 (_data_->details1);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_clear_error (&_data_->_inner_error_);
#line 162 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			return FALSE;
#line 1300 "link-personas-diff-stores.c"
		}
	}
	goto __finally1;
	__catch1_folks_individual_aggregator_error:
	{
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->e = _data_->_inner_error_;
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_inner_error_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp34_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp34_ = _data_->e;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp35_ = NULL;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp35_ = _data_->_tmp34_->message;
#line 167 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_warning ("link-personas-diff-stores.vala:167: [AddPersonaError] add_persona_from" \
"_details: %s\n", _data_->_tmp35_);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_error_free0 (_data_->e);
#line 1322 "link-personas-diff-stores.c"
	}
	__finally1:
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_inner_error_ != NULL) {
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		__vala_GValue_free0 (_data_->v2);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_hash_table_unref0 (_data_->details2);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		__vala_GValue_free0 (_data_->v1);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_hash_table_unref0 (_data_->details1);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_clear_error (&_data_->_inner_error_);
#line 157 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 1341 "link-personas-diff-stores.c"
	}
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	__vala_GValue_free0 (_data_->v2);
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_hash_table_unref0 (_data_->details2);
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	__vala_GValue_free0 (_data_->v1);
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_hash_table_unref0 (_data_->details1);
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_state_ == 0) {
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1355 "link-personas-diff-stores.c"
	} else {
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1359 "link-personas-diff-stores.c"
	}
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_object_unref (_data_->_async_result);
#line 143 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return FALSE;
#line 1365 "link-personas-diff-stores.c"
}


static void __lambda3_ (LinkPersonasDiffStoresTests* self, GObject* object, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (_result_ != NULL);
#line 177 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = _result_;
#line 177 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_individuals_changed_finish (self, _tmp0_);
#line 1377 "link-personas-diff-stores.c"
}


static void ___lambda3__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 175 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	__lambda3_ ((LinkPersonasDiffStoresTests*) self, source_object, res);
#line 175 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_object_unref (self);
#line 1386 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_individuals_changed_cb (LinkPersonasDiffStoresTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_ = NULL;
#line 172 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (self != NULL);
#line 172 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_return_if_fail (changes != NULL);
#line 175 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = changes;
#line 175 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_individuals_changed_async (self, _tmp0_, ___lambda3__gasync_ready_callback, g_object_ref (self));
#line 1400 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_individuals_changed_async_data_free (gpointer _data) {
	LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->changes);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_slice_free (LinkPersonasDiffStoresTestsIndividualsChangedAsyncData, _data_);
#line 1413 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_individuals_changed_async (LinkPersonasDiffStoresTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_;
	LinkPersonasDiffStoresTests* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_slice_new0 (LinkPersonasDiffStoresTestsIndividualsChangedAsyncData);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_diff_stores_tests_individuals_changed_async);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_diff_stores_tests_individuals_changed_async_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = changes;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->changes);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->changes = _tmp2_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_individuals_changed_async_co (_data_);
#line 1442 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_individuals_changed_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_) {
	LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1450 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_individuals_changed_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = _user_data_;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_source_object_ = source_object;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_res_ = _res_;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_individuals_changed_async_co (_data_);
#line 1464 "link-personas-diff-stores.c"
}


static gboolean _link_personas_diff_stores_tests_individuals_changed_async_co (LinkPersonasDiffStoresTestsIndividualsChangedAsyncData* _data_) {
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	switch (_data_->_state_) {
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 0:
#line 1473 "link-personas-diff-stores.c"
		goto _state_0;
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 1:
#line 1477 "link-personas-diff-stores.c"
		goto _state_1;
		default:
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_assert_not_reached ();
#line 1482 "link-personas-diff-stores.c"
	}
	_state_0:
#line 184 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = _data_->changes;
#line 184 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = NULL;
#line 184 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp1_ = gee_multi_map_get_values (_data_->_tmp0_);
#line 184 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->added = _data_->_tmp1_;
#line 1495 "link-personas-diff-stores.c"
	{
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp2_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp2_ = _data_->added;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp2_);
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_i_it = _data_->_tmp3_;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		while (TRUE) {
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp4_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp4_ = _data_->_i_it;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp5_ = FALSE;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp5_ = gee_iterator_next (_data_->_tmp4_);
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (!_data_->_tmp5_) {
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				break;
#line 1521 "link-personas-diff-stores.c"
			}
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp6_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp6_ = _data_->_i_it;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp7_ = NULL;
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp7_ = gee_iterator_get (_data_->_tmp6_);
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->i = (FolksIndividual*) _data_->_tmp7_;
#line 188 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp8_ = NULL;
#line 188 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp8_ = _data_->i;
#line 188 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_data_->_tmp8_ == NULL) {
#line 190 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_g_object_unref0 (_data_->i);
#line 190 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				continue;
#line 1543 "link-personas-diff-stores.c"
			}
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp9_ = NULL;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp9_ = _data_->i;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_state_ = 1;
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_link_personas_diff_stores_tests_check_personas (_data_->self, _data_->_tmp9_, _link_personas_diff_stores_tests_individuals_changed_async_ready, _data_);
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			return FALSE;
#line 1555 "link-personas-diff-stores.c"
			_state_1:
#line 193 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_link_personas_diff_stores_tests_check_personas_finish (_data_->self, _data_->_res_);
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (_data_->i);
#line 1561 "link-personas-diff-stores.c"
		}
#line 186 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_data_->_i_it);
#line 1565 "link-personas-diff-stores.c"
	}
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->added);
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_state_ == 0) {
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1573 "link-personas-diff-stores.c"
	} else {
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1577 "link-personas-diff-stores.c"
	}
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_object_unref (_data_->_async_result);
#line 181 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return FALSE;
#line 1583 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_check_personas_data_free (gpointer _data) {
	LinkPersonasDiffStoresTestsCheckPersonasData* _data_;
	_data_ = _data;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->i);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_slice_free (LinkPersonasDiffStoresTestsCheckPersonasData, _data_);
#line 1596 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_check_personas (LinkPersonasDiffStoresTests* self, FolksIndividual* i, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsCheckPersonasData* _data_;
	LinkPersonasDiffStoresTests* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_slice_new0 (LinkPersonasDiffStoresTestsCheckPersonasData);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _link_personas_diff_stores_tests_check_personas);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _link_personas_diff_stores_tests_check_personas_data_free);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->self = _tmp0_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp1_ = i;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->i);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->i = _tmp2_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_check_personas_co (_data_);
#line 1625 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_check_personas_finish (LinkPersonasDiffStoresTests* self, GAsyncResult* _res_) {
	LinkPersonasDiffStoresTestsCheckPersonasData* _data_;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1633 "link-personas-diff-stores.c"
}


static void _link_personas_diff_stores_tests_check_personas_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	LinkPersonasDiffStoresTestsCheckPersonasData* _data_;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_ = _user_data_;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_source_object_ = source_object;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_res_ = _res_;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_link_personas_diff_stores_tests_check_personas_co (_data_);
#line 1647 "link-personas-diff-stores.c"
}


static gboolean _link_personas_diff_stores_tests_check_personas_co (LinkPersonasDiffStoresTestsCheckPersonasData* _data_) {
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	switch (_data_->_state_) {
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 0:
#line 1656 "link-personas-diff-stores.c"
		goto _state_0;
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		case 1:
#line 1660 "link-personas-diff-stores.c"
		goto _state_1;
		default:
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_assert_not_reached ();
#line 1665 "link-personas-diff-stores.c"
	}
	_state_0:
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = FALSE;
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp0_ = _data_->self->priv->_linked_individual_found;
#line 210 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_tmp0_ == TRUE) {
#line 211 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_state_ == 0) {
#line 211 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1678 "link-personas-diff-stores.c"
		} else {
#line 211 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1682 "link-personas-diff-stores.c"
		}
#line 211 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_object_unref (_data_->_async_result);
#line 211 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		return FALSE;
#line 1688 "link-personas-diff-stores.c"
	}
#line 213 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->first_persona = NULL;
#line 1692 "link-personas-diff-stores.c"
	{
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp1_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp1_ = _data_->i;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp2_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp2_ = folks_individual_get_personas (_data_->_tmp1_);
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp4_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp4_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp3_);
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_p_it = _data_->_tmp4_;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		while (TRUE) {
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp5_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp5_ = _data_->_p_it;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp6_ = FALSE;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp6_ = gee_iterator_next (_data_->_tmp5_);
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (!_data_->_tmp6_) {
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				break;
#line 1726 "link-personas-diff-stores.c"
			}
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp7_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp7_ = _data_->_p_it;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp8_ = NULL;
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp8_ = gee_iterator_get (_data_->_tmp7_);
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->p = (FolksPersona*) _data_->_tmp8_;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp9_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp9_ = _data_->p;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp10_ = NULL;
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp10_ = _g_object_ref0 (_data_->_tmp9_);
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (_data_->first_persona);
#line 216 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->first_persona = _data_->_tmp10_;
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (_data_->p);
#line 217 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			break;
#line 1754 "link-personas-diff-stores.c"
		}
#line 214 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_object_unref0 (_data_->_p_it);
#line 1758 "link-personas-diff-stores.c"
	}
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp12_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp12_ = _data_->i;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp13_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp13_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp12_);
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp14_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp15_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp15_ = _data_->self->priv->_persona_fullname_1;
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (g_strcmp0 (_data_->_tmp14_, _data_->_tmp15_) == 0) {
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp16_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp16_ = _data_->self->priv->_persona_iid_1;
#line 221 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp11_ = g_strcmp0 (_data_->_tmp16_, "") == 0;
#line 1784 "link-personas-diff-stores.c"
	} else {
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp11_ = FALSE;
#line 1788 "link-personas-diff-stores.c"
	}
#line 220 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_tmp11_) {
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp17_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp17_ = _data_->first_persona;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp18_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp18_ = folks_persona_get_iid (_data_->_tmp17_);
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp19_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp19_ = _data_->_tmp18_;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp20_ = NULL;
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_g_free0 (_data_->self->priv->_persona_iid_1);
#line 223 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->self->priv->_persona_iid_1 = _data_->_tmp20_;
#line 224 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp21_ = NULL;
#line 224 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp21_ = _data_->self->priv->_personas;
#line 224 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp22_ = NULL;
#line 224 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp22_ = _data_->first_persona;
#line 224 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp21_, _data_->_tmp22_);
#line 1822 "link-personas-diff-stores.c"
	} else {
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp24_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp24_ = _data_->i;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp25_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp25_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp24_);
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp26_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp26_ = _data_->_tmp25_;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp27_ = NULL;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp27_ = _data_->self->priv->_persona_fullname_2;
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (g_strcmp0 (_data_->_tmp26_, _data_->_tmp27_) == 0) {
#line 227 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp28_ = NULL;
#line 227 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp28_ = _data_->self->priv->_persona_iid_2;
#line 227 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp23_ = g_strcmp0 (_data_->_tmp28_, "") == 0;
#line 1848 "link-personas-diff-stores.c"
		} else {
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp23_ = FALSE;
#line 1852 "link-personas-diff-stores.c"
		}
#line 226 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_tmp23_) {
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp29_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp29_ = _data_->first_persona;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp30_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp30_ = folks_persona_get_iid (_data_->_tmp29_);
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp31_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp31_ = _data_->_tmp30_;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp32_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp32_ = g_strdup (_data_->_tmp31_);
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_free0 (_data_->self->priv->_persona_iid_2);
#line 229 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->self->priv->_persona_iid_2 = _data_->_tmp32_;
#line 230 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp33_ = NULL;
#line 230 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp33_ = _data_->self->priv->_personas;
#line 230 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp34_ = NULL;
#line 230 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp34_ = _data_->first_persona;
#line 230 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp33_, _data_->_tmp34_);
#line 1886 "link-personas-diff-stores.c"
		} else {
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp35_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp35_ = _data_->i;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp36_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp36_ = folks_individual_get_personas (_data_->_tmp35_);
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp37_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp37_ = _data_->_tmp36_;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp38_ = 0;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp38_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp37_);
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp39_ = 0;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp39_ = _data_->_tmp38_;
#line 232 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_data_->_tmp39_ > 1) {
#line 234 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_data_->first_persona_id = FALSE;
#line 235 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_data_->second_persona_id = FALSE;
#line 1914 "link-personas-diff-stores.c"
				{
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp40_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp40_ = _data_->i;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp41_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp41_ = folks_individual_get_personas (_data_->_tmp40_);
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp42_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp42_ = _data_->_tmp41_;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp43_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp43_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp42_);
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_p1_it = _data_->_tmp43_;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					while (TRUE) {
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp44_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp44_ = _data_->_p1_it;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp45_ = FALSE;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp45_ = gee_iterator_next (_data_->_tmp44_);
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						if (!_data_->_tmp45_) {
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							break;
#line 1948 "link-personas-diff-stores.c"
						}
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp46_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp46_ = _data_->_p1_it;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp47_ = NULL;
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp47_ = gee_iterator_get (_data_->_tmp46_);
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->p1 = (FolksPersona*) _data_->_tmp47_;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp48_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp48_ = _data_->p1;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp49_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp49_ = folks_persona_get_iid (_data_->_tmp48_);
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp50_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp50_ = _data_->_tmp49_;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp51_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_data_->_tmp51_ = _data_->self->priv->_persona_iid_1;
#line 239 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						if (g_strcmp0 (_data_->_tmp50_, _data_->_tmp51_) == 0) {
#line 240 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->first_persona_id = TRUE;
#line 1980 "link-personas-diff-stores.c"
						} else {
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp52_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp52_ = _data_->p1;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp53_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp53_ = folks_persona_get_iid (_data_->_tmp52_);
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp54_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp54_ = _data_->_tmp53_;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp55_ = NULL;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							_data_->_tmp55_ = _data_->self->priv->_persona_iid_2;
#line 241 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
							if (g_strcmp0 (_data_->_tmp54_, _data_->_tmp55_) == 0) {
#line 242 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
								_data_->second_persona_id = TRUE;
#line 2002 "link-personas-diff-stores.c"
							}
						}
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
						_g_object_unref0 (_data_->p1);
#line 2007 "link-personas-diff-stores.c"
					}
#line 237 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_g_object_unref0 (_data_->_p1_it);
#line 2011 "link-personas-diff-stores.c"
				}
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_data_->_tmp57_ = FALSE;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				_data_->_tmp57_ = _data_->first_persona_id;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				if (_data_->_tmp57_) {
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp58_ = FALSE;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp58_ = _data_->second_persona_id;
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp56_ = _data_->_tmp58_;
#line 2025 "link-personas-diff-stores.c"
				} else {
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp56_ = FALSE;
#line 2029 "link-personas-diff-stores.c"
				}
#line 245 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
				if (_data_->_tmp56_) {
#line 247 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->self->priv->_linked_individual_found = TRUE;
#line 248 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp59_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					_data_->_tmp59_ = _data_->self->priv->_main_loop;
#line 248 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
					g_main_loop_quit (_data_->_tmp59_);
#line 2041 "link-personas-diff-stores.c"
				}
			}
		}
	}
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp61_ = NULL;
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp61_ = _data_->self->priv->_personas;
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp62_ = 0;
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp62_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp61_);
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp63_ = 0;
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_data_->_tmp63_ = _data_->_tmp62_;
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_tmp63_ == 2) {
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp64_ = FALSE;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp64_ = _data_->self->priv->_linking_fired;
#line 255 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp60_ = _data_->_tmp64_ == FALSE;
#line 2066 "link-personas-diff-stores.c"
	} else {
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->_tmp60_ = FALSE;
#line 2070 "link-personas-diff-stores.c"
	}
#line 254 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_tmp60_) {
#line 257 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		_data_->self->priv->_linking_fired = TRUE;
#line 2076 "link-personas-diff-stores.c"
		{
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp65_ = NULL;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp65_ = _data_->self->priv->_aggregator;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp66_ = NULL;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp66_ = _data_->self->priv->_personas;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_state_ = 1;
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			folks_individual_aggregator_link_personas (_data_->_tmp65_, (GeeSet*) _data_->_tmp66_, _link_personas_diff_stores_tests_check_personas_ready, _data_);
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			return FALSE;
#line 2092 "link-personas-diff-stores.c"
			_state_1:
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			folks_individual_aggregator_link_personas_finish (_data_->_tmp65_, _data_->_res_, &_data_->_inner_error_);
#line 260 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			if (_data_->_inner_error_ != NULL) {
#line 2098 "link-personas-diff-stores.c"
				goto __catch2_g_error;
			}
		}
		goto __finally2;
		__catch2_g_error:
		{
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->e = _data_->_inner_error_;
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_inner_error_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp67_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp67_ = _data_->e;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp68_ = NULL;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_data_->_tmp68_ = _data_->_tmp67_->message;
#line 264 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_warning ("link-personas-diff-stores.vala:264: link_personas: %s\n", _data_->_tmp68_);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_error_free0 (_data_->e);
#line 2121 "link-personas-diff-stores.c"
		}
		__finally2:
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		if (_data_->_inner_error_ != NULL) {
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			_g_object_unref0 (_data_->first_persona);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			g_clear_error (&_data_->_inner_error_);
#line 258 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
			return FALSE;
#line 2134 "link-personas-diff-stores.c"
		}
	}
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (_data_->first_persona);
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	if (_data_->_state_ == 0) {
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2143 "link-personas-diff-stores.c"
	} else {
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2147 "link-personas-diff-stores.c"
	}
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_object_unref (_data_->_async_result);
#line 207 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return FALSE;
#line 2153 "link-personas-diff-stores.c"
}


static void link_personas_diff_stores_tests_class_init (LinkPersonasDiffStoresTestsClass * klass) {
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	link_personas_diff_stores_tests_parent_class = g_type_class_peek_parent (klass);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_type_class_add_private (klass, sizeof (LinkPersonasDiffStoresTestsPrivate));
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = link_personas_diff_stores_tests_real_set_up;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = link_personas_diff_stores_tests_real_tear_down;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	G_OBJECT_CLASS (klass)->finalize = link_personas_diff_stores_tests_finalize;
#line 2168 "link-personas-diff-stores.c"
}


static void link_personas_diff_stores_tests_instance_init (LinkPersonasDiffStoresTests * self) {
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self->priv = LINK_PERSONAS_DIFF_STORES_TESTS_GET_PRIVATE (self);
#line 2175 "link-personas-diff-stores.c"
}


static void link_personas_diff_stores_tests_finalize (GObject* obj) {
	LinkPersonasDiffStoresTests * self;
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LINK_PERSONAS_DIFF_STORES_TESTS, LinkPersonasDiffStoresTests);
#line 26 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_main_loop_unref0 (self->priv->_main_loop);
#line 27 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_eds_test_backend_unref0 (self->priv->_eds_backend_other);
#line 28 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 29 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_fullname_1);
#line 30 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_fullname_2);
#line 33 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_iid_1);
#line 34 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_free0 (self->priv->_persona_iid_2);
#line 35 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (self->priv->_personas);
#line 24 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	G_OBJECT_CLASS (link_personas_diff_stores_tests_parent_class)->finalize (obj);
#line 2201 "link-personas-diff-stores.c"
}


GType link_personas_diff_stores_tests_get_type (void) {
	static volatile gsize link_personas_diff_stores_tests_type_id__volatile = 0;
	if (g_once_init_enter (&link_personas_diff_stores_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LinkPersonasDiffStoresTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) link_personas_diff_stores_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LinkPersonasDiffStoresTests), 0, (GInstanceInitFunc) link_personas_diff_stores_tests_instance_init, NULL };
		GType link_personas_diff_stores_tests_type_id;
		link_personas_diff_stores_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "LinkPersonasDiffStoresTests", &g_define_type_info, 0);
		g_once_init_leave (&link_personas_diff_stores_tests_type_id__volatile, link_personas_diff_stores_tests_type_id);
	}
	return link_personas_diff_stores_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	LinkPersonasDiffStoresTests* tests = NULL;
	LinkPersonasDiffStoresTests* _tmp0_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_test_init (&args_length1, &args, NULL);
#line 274 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_tmp0_ = link_personas_diff_stores_tests_new ();
#line 274 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	tests = _tmp0_;
#line 275 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 276 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	g_test_run ();
#line 277 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 279 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	result = 0;
#line 279 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	_g_object_unref0 (tests);
#line 279 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return result;
#line 2239 "link-personas-diff-stores.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 270 "/opt/gnome3/source/folks/tests/eds/link-personas-diff-stores.vala"
	return _vala_main (argv, argc);
#line 2249 "link-personas-diff-stores.c"
}



